@@ -35,7 +35,7 @@ HttpApiTagName = "httpapi:createdBy"
 
 
 class HttpApiGenerator:
-    def __init__(  # noqa: too-many-arguments
+    def __init__(  # noqa: PLR0913
         self,
         logical_id: str,
         stage_variables: Optional[Dict[str, Intrinsicable[str]]],
@@ -187,8 +187,9 @@ class HttpApiGenerator:
 
         elif isinstance(self.cors_configuration, dict):
             # Make sure keys in the dict are recognized
-            if not all(key in CorsProperties._fields for key in self.cors_configuration):
-                raise InvalidResourceException(self.logical_id, "Invalid value for 'Cors' property.")
+            for key in self.cors_configuration:
+                if key not in CorsProperties._fields:
+                    raise InvalidResourceException(self.logical_id, f"Invalid key '{key}' for 'Cors' property.")
 
             properties = CorsProperties(**self.cors_configuration)
 
@@ -239,7 +240,7 @@ class HttpApiGenerator:
         if DefaultStageName in paths:
             paths[f"/{DefaultStageName}"] = paths.pop(DefaultStageName)
 
-    def _construct_api_domain(  # noqa: too-many-branches
+    def _construct_api_domain(  # noqa: PLR0912, PLR0915
         self, http_api: ApiGatewayV2HttpApi, route53_record_set_groups: Dict[str, Route53RecordSetGroup]
     ) -> Tuple[
         Optional[ApiGatewayV2DomainName],
@@ -633,8 +634,7 @@ class HttpApiGenerator:
             if "OpenIdConnectUrl" in authorizer:
                 raise InvalidResourceException(
                     self.logical_id,
-                    "'OpenIdConnectUrl' is no longer a supported property for authorizer '%s'. Please refer to the AWS SAM documentation."
-                    % (authorizer_name),
+                    f"'OpenIdConnectUrl' is no longer a supported property for authorizer '{authorizer_name}'. Please refer to the AWS SAM documentation.",
                 )
             authorizers[authorizer_name] = ApiGatewayV2Authorizer(  # type: ignore[no-untyped-call]
                 api_logical_id=self.logical_id,
@@ -735,7 +735,7 @@ class HttpApiGenerator:
         except InvalidValueType as ex:
             raise InvalidResourceException(
                 self.logical_id,
-                f"Invalid 'DefinitionBody': {str(ex)}'.",
+                f"Invalid 'DefinitionBody': {ex!s}'.",
             ) from ex
         if description_in_definition_body:
             raise InvalidResourceException(
@@ -763,7 +763,7 @@ class HttpApiGenerator:
         except InvalidValueType as ex:
             raise InvalidResourceException(
                 self.logical_id,
-                f"Invalid 'DefinitionBody': {str(ex)}.",
+                f"Invalid 'DefinitionBody': {ex!s}.",
             ) from ex
         if title_in_definition_body != OpenApiEditor._DEFAULT_OPENAPI_TITLE:
             raise InvalidResourceException(
@@ -777,9 +777,7 @@ class HttpApiGenerator:
         self.definition_body = open_api_editor.openapi
 
     @cw_timer(prefix="Generator", name="HttpApi")
-    def to_cloudformation(
-        self, route53_record_set_groups: Dict[str, Route53RecordSetGroup]
-    ) -> Tuple[
+    def to_cloudformation(self, route53_record_set_groups: Dict[str, Route53RecordSetGroup]) -> Tuple[
         ApiGatewayV2HttpApi,
         Optional[ApiGatewayV2Stage],
         Optional[ApiGatewayV2DomainName],
