@@ -2,6 +2,7 @@ from abc import ABCMeta, abstractmethod
 from typing import Any, Dict, List, Optional, Tuple
 
 from samtranslator.internal.deprecation_control import deprecated
+from samtranslator.intrinsics.resolver import IntrinsicsResolver
 from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model import PassThroughProperty, Property, PropertyType, ResourceMacro
 from samtranslator.model.eventsources import FUNCTION_EVETSOURCE_METRIC_PREFIX
@@ -25,6 +26,8 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
     :cvar str policy_arn: The ARN of the AWS managed role policy corresponding to this pull event source
     """
 
+    ARN_SEGMENTS_COUNT = 6
+    REGISTRY_SEGMENT_POS_IN_ARN = 5
     # Event types that support `FilterCriteria`, stored as a list to keep the alphabetical order
     RESOURCE_TYPES_WITH_EVENT_FILTERING = ["DocumentDB", "DynamoDB", "Kinesis", "MQ", "MSK", "SelfManagedKafka", "SQS"]
 
@@ -56,6 +59,7 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
         "ConsumerGroupId": PropertyType(False, IS_STR),
         "ScalingConfig": PropertyType(False, IS_DICT),
         "ProvisionedPollerConfig": PropertyType(False, IS_DICT),
+        "SchemaRegistryConfig": PropertyType(False, IS_DICT),
         "MetricsConfig": PropertyType(False, IS_DICT),
     }
 
@@ -81,6 +85,7 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
     ConsumerGroupId: Optional[Intrinsicable[str]]
     ScalingConfig: Optional[Dict[str, Any]]
     ProvisionedPollerConfig: Optional[Dict[str, Any]]
+    SchemaRegistryConfig: Optional[Dict[str, Any]]
     MetricsConfig: Optional[Dict[str, Any]]
 
     @abstractmethod
@@ -88,7 +93,9 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
         """Policy to be added to the role (if a role applies)."""
 
     @abstractmethod
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         """Inline policy statements to be added to the role (if a role applies)."""
 
     @abstractmethod
@@ -113,6 +120,7 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
         :rtype: list
         """
         function = kwargs.get("function")
+        intrinsic_resolver = kwargs.get("intrinsics_resolver")
 
         if not function:
             raise TypeError("Missing required keyword argument: function")
@@ -168,7 +176,19 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
                     self.logical_id,
                     f"Property ConsumerGroupId not defined for resource of type {self.resource_type}.",
                 )
-
+        if self.SchemaRegistryConfig:
+            if self.resource_type == "MSK":
+                if not lambda_eventsourcemapping.AmazonManagedKafkaEventSourceConfig:  # type: ignore[attr-defined]
+                    lambda_eventsourcemapping.AmazonManagedKafkaEventSourceConfig = {}
+                lambda_eventsourcemapping.AmazonManagedKafkaEventSourceConfig["SchemaRegistryConfig"] = (  # type: ignore[attr-defined]
+                    self.SchemaRegistryConfig
+                )
+            if self.resource_type == "SelfManagedKafka":
+                if not lambda_eventsourcemapping.SelfManagedKafkaEventSourceConfig:  # type: ignore[attr-defined]
+                    lambda_eventsourcemapping.SelfManagedKafkaEventSourceConfig = {}
+                lambda_eventsourcemapping.SelfManagedKafkaEventSourceConfig["SchemaRegistryConfig"] = (  # type: ignore[attr-defined]
+                    self.SchemaRegistryConfig
+                )
         destination_config_policy: Optional[Dict[str, Any]] = None
         if self.DestinationConfig:
             on_failure: Dict[str, Any] = sam_expect(
@@ -185,10 +205,10 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
             if destination_type:
                 # delete this field as its used internally for SAM to determine the policy
                 del on_failure["Type"]
-                # the values 'SQS', 'SNS', and 'S3' are allowed. No intrinsics are allowed
-                if destination_type not in ["SQS", "SNS", "S3"]:
+                # the values 'SQS', 'SNS', 'S3', and 'Kafka' are allowed. No intrinsics are allowed
+                if destination_type not in ["SQS", "SNS", "S3", "Kafka"]:
                     raise InvalidEventException(
-                        self.logical_id, "The only valid values for 'Type' are 'SQS', 'SNS', and 'S3'"
+                        self.logical_id, "The only valid values for 'Type' are 'SQS', 'SNS', 'S3', and 'Kafka'"
                     )
                 if destination_type == "SQS":
                     queue_arn = on_failure.get("Destination")
@@ -205,24 +225,27 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
                     destination_config_policy = IAMRolePolicies().s3_send_event_payload_role_policy(
                         s3_arn, self.logical_id
                     )
+                elif destination_type == "Kafka":
+                    # No policy generation for Kafka destinations - pass through
+                    pass
 
             lambda_eventsourcemapping.DestinationConfig = self.DestinationConfig
 
         self.add_extra_eventsourcemapping_fields(lambda_eventsourcemapping)
 
         if "role" in kwargs:
-            self._link_policy(kwargs["role"], destination_config_policy)  # type: ignore[no-untyped-call]
+            self._link_policy(kwargs["role"], intrinsic_resolver, destination_config_policy)  # type: ignore[no-untyped-call]
 
         return resources
 
-    def _link_policy(self, role, destination_config_policy=None):  # type: ignore[no-untyped-def]
+    def _link_policy(self, role, intrinsic_resolver=None, destination_config_policy=None):  # type: ignore[no-untyped-def]
         """If this source triggers a Lambda function whose execution role is auto-generated by SAM, add the
         appropriate managed policy to this Role.
 
         :param model.iam.IAMRole role: the execution role generated for the function
         """
         policy_arn = self.get_policy_arn()
-        policy_statements = self.get_policy_statements()
+        policy_statements = self.get_policy_statements(intrinsic_resolver)
         if role is not None:
             if policy_arn is not None and policy_arn not in role.ManagedPolicyArns:
                 role.ManagedPolicyArns.append(policy_arn)
@@ -324,6 +347,99 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
             },
         }
 
+    def validate_schema_registry_config(self) -> None:
+        if not self.SchemaRegistryConfig:
+            return
+
+        sam_expect(self.SchemaRegistryConfig, self.relative_id, "SchemaRegistryConfig", is_sam_event=True).to_be_a_map()
+        required_fields = ["SchemaRegistryURI", "EventRecordFormat", "SchemaValidationConfigs"]
+        for field in required_fields:
+            if field not in self.SchemaRegistryConfig:
+                raise InvalidEventException(self.relative_id, f"Missing required field {field} in SchemaRegistryConfig")
+
+        event_record_format = self.SchemaRegistryConfig.get("EventRecordFormat")
+        if event_record_format not in ["JSON", "SOURCE"]:
+            raise InvalidEventException(
+                self.relative_id, "EventRecordFormat in SchemaRegistryConfig must be either 'JSON' or 'SOURCE'"
+            )
+
+        validation_configs = self.SchemaRegistryConfig.get("SchemaValidationConfigs")
+        if not isinstance(validation_configs, list):
+            raise InvalidEventException(self.relative_id, "SchemaValidationConfigs must be a list")
+
+        access_configs = self.SchemaRegistryConfig.get("AccessConfigs", [])
+        if access_configs:
+            if not isinstance(access_configs, list):
+                raise InvalidEventException(self.relative_id, "AccessConfigs in SchemaRegistryConfig must be a list")
+            for config in access_configs:
+                if not isinstance(config, dict) or "Type" not in config or "URI" not in config:
+                    raise InvalidEventException(
+                        self.relative_id, "Each AccessConfig must be a dict with 'Type' and 'URI' fields"
+                    )
+
+    def get_schema_registry_permissions(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
+
+        if not self.SchemaRegistryConfig:
+            return None
+
+        self.validate_schema_registry_config()
+
+        statements = []
+
+        # Add permissions for AccessConfigs secrets if provided
+        access_configs = self.SchemaRegistryConfig.get("AccessConfigs", [])
+        for config in access_configs:
+            if isinstance(config, dict) and "URI" in config:
+                statements.append(
+                    {
+                        "Action": [
+                            "secretsmanager:GetSecretValue",
+                        ],
+                        "Effect": "Allow",
+                        "Resource": config["URI"],
+                    }
+                )
+
+        registry_uri = self.SchemaRegistryConfig.get("SchemaRegistryURI")
+        registry_arn = None
+        ## resolved_value is still going to be a dict if intrinsic functions are used. Otherwise, it'd be a string.
+        if isinstance(registry_uri, str):
+            registry_arn = registry_uri
+        elif isinstance(registry_uri, dict) and intrinsic_resolver is not None:
+            ## We can't handle other intrinsic functions in SAM. Don't pass original dictionary
+
+            resolved_value = intrinsic_resolver.resolve_parameter_refs(registry_uri.copy())
+            registry_arn = resolved_value.get("Fn::Sub")
+
+        registry_name_optional = self.get_registry_name(str(registry_arn))
+        if registry_name_optional is not None:
+            statements.append({"Action": ["glue:GetRegistry"], "Effect": "Allow", "Resource": registry_uri})
+            statements.append(
+                {
+                    "Action": ["glue:GetSchemaVersion"],
+                    "Effect": "Allow",
+                    "Resource": [
+                        {
+                            "Fn::Sub": "arn:${AWS::Partition}:glue:${AWS::Region}:${AWS::AccountId}:schema/"
+                            + registry_name_optional
+                            + "/*"
+                        },
+                    ],
+                }
+            )
+        return statements
+
+    def get_registry_name(self, registry_uri: str) -> Optional[str]:
+        if isinstance(registry_uri, str) and registry_uri.startswith("arn"):
+            parts = registry_uri.split(":")
+            if len(parts) >= PullEventSource.ARN_SEGMENTS_COUNT and parts[
+                PullEventSource.REGISTRY_SEGMENT_POS_IN_ARN
+            ].startswith("registry/"):
+                return parts[PullEventSource.REGISTRY_SEGMENT_POS_IN_ARN][len("registry/") :]
+        return None
+
 
 class Kinesis(PullEventSource):
     """Kinesis event source."""
@@ -343,7 +459,9 @@ class Kinesis(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaKinesisExecutionRole")
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         return None
 
 
@@ -365,7 +483,9 @@ class DynamoDB(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaDynamoDBExecutionRole")
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         return None
 
 
@@ -386,7 +506,9 @@ class SQS(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaSQSQueueExecutionRole")
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         return None
 
 
@@ -408,29 +530,30 @@ class MSK(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return ArnGenerator.generate_aws_managed_policy_arn("service-role/AWSLambdaMSKExecutionRole")
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
+        statements: List[Dict[str, Any]] = []
+        if self.SchemaRegistryConfig:
+            schema_registry_statements = self.get_schema_registry_permissions(intrinsic_resolver)
+            if schema_registry_statements is not None:
+                statements.extend(schema_registry_statements)
         if self.SourceAccessConfigurations:
             for conf in self.SourceAccessConfigurations:
                 # Lambda does not support multiple CLIENT_CERTIFICATE_TLS_AUTH configurations
                 if isinstance(conf, dict) and conf.get("Type") == "CLIENT_CERTIFICATE_TLS_AUTH" and conf.get("URI"):
-                    return [
+                    statements.append(
                         {
-                            "PolicyName": "MSKExecutionRolePolicy",
-                            "PolicyDocument": {
-                                "Statement": [
-                                    {
-                                        "Action": [
-                                            "secretsmanager:GetSecretValue",
-                                        ],
-                                        "Effect": "Allow",
-                                        "Resource": conf.get("URI"),
-                                    }
-                                ]
-                            },
+                            "Action": [
+                                "secretsmanager:GetSecretValue",
+                            ],
+                            "Effect": "Allow",
+                            "Resource": conf.get("URI"),
                         }
-                    ]
-
-        return None
+                    )
+        if not statements:
+            return None
+        return [{"PolicyName": "MSKExecutionRolePolicy", "PolicyDocument": {"Statement": statements}}]
 
 
 class MQ(PullEventSource):
@@ -487,7 +610,9 @@ class MQ(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return None
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         basic_auth_uri = self._validate_source_access_configurations(["BASIC_AUTH", "VIRTUAL_HOST"], "BASIC_AUTH")
 
         document = {
@@ -544,7 +669,9 @@ class SelfManagedKafka(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return None
 
-    def get_policy_statements(self) -> Optional[List[Dict[str, Any]]]:
+    def get_policy_statements(
+        self, intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ) -> Optional[List[Dict[str, Any]]]:
         if not self.KafkaBootstrapServers:
             raise InvalidEventException(
                 self.relative_id,
@@ -568,10 +695,12 @@ class SelfManagedKafka(PullEventSource):
                 self.relative_id,
                 "No SourceAccessConfigurations for self managed kafka event provided.",
             )
-        document = self.generate_policy_document(self.SourceAccessConfigurations)
+        document = self.generate_policy_document(self.SourceAccessConfigurations, intrinsic_resolver)
         return [document]
 
-    def generate_policy_document(self, source_access_configurations: List[Any]):  # type: ignore[no-untyped-def]
+    def generate_policy_document(  # type: ignore[no-untyped-def]
+        self, source_access_configurations: List[Any], intrinsic_resolver: Optional[IntrinsicsResolver] = None
+    ):
         statements = []
         authentication_uri, authentication_uri_2, has_vpc_config = self.get_secret_key(source_access_configurations)
         if authentication_uri:
@@ -591,6 +720,12 @@ class SelfManagedKafka(PullEventSource):
             kms_policy = self._get_kms_decrypt_policy(self.SecretsManagerKmsKeyId)
             statements.append(kms_policy)
 
+        # Add schema registry permissions if configured
+        if self.SchemaRegistryConfig:
+            schema_registry_statements = self.get_schema_registry_permissions(intrinsic_resolver)
+            if schema_registry_statements is not None:
+                statements.extend(schema_registry_statements)
+
         return {
             "PolicyDocument": {
                 "Statement": statements,
@@ -725,7 +860,7 @@ class DocumentDB(PullEventSource):
     def get_policy_arn(self) -> Optional[str]:
         return None
 
-    def get_policy_statements(self) -> List[Dict[str, Any]]:
+    def get_policy_statements(self, intrinsic_resolver: Optional[IntrinsicsResolver] = None) -> List[Dict[str, Any]]:
         basic_auth_uri = self._validate_source_access_configurations(["BASIC_AUTH"], "BASIC_AUTH")
 
         statements = [
