@@ -36,7 +36,11 @@ class LambdaFunction(Resource):
         "RuntimeManagementConfig": GeneratedProperty(),
         "LoggingConfig": GeneratedProperty(),
         "RecursiveLoop": GeneratedProperty(),
+        "CapacityProviderConfig": GeneratedProperty(),
+        "FunctionScalingConfig": GeneratedProperty(),
+        "PublishToLatestPublished": GeneratedProperty(),
         "TenancyConfig": GeneratedProperty(),
+        "DurableConfig": GeneratedProperty(),
     }
 
     Code: Dict[str, Any]
@@ -65,7 +69,11 @@ class LambdaFunction(Resource):
     RuntimeManagementConfig: Optional[Dict[str, Any]]
     LoggingConfig: Optional[Dict[str, Any]]
     RecursiveLoop: Optional[str]
+    CapacityProviderConfig: Optional[Dict[str, Any]]
+    FunctionScalingConfig: Optional[Dict[str, Any]]
+    PublishToLatestPublished: Optional[Dict[str, Any]]
     TenancyConfig: Optional[Dict[str, Any]]
+    DurableConfig: Optional[Dict[str, Any]]
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id), "arn": lambda self: fnGetAtt(self.logical_id, "Arn")}
 
@@ -76,6 +84,7 @@ class LambdaVersion(Resource):
         "CodeSha256": GeneratedProperty(),
         "Description": GeneratedProperty(),
         "FunctionName": GeneratedProperty(),
+        "FunctionScalingConfig": GeneratedProperty(),
     }
 
     runtime_attrs = {
